@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class StatsConfig(AppConfig):
-    name = 'stats'
+    name = 'stats_dashboard'
